@@ -1,5 +1,4 @@
 
-# $Id: Ace.pm,v 1.7.2.2 2001/06/18 16:00:26 dag Exp $
 #
 # BioPerl module for Bio::DB::Ace
 #
@@ -58,8 +57,9 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
+  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
+  http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -83,12 +83,12 @@ The rest of the documentation details each of the object methods. Internal metho
 # Let the code begin...
 
 package Bio::DB::Ace;
-use vars qw(@ISA);
+use vars qw($AUTOLOAD @ISA @EXPORT_OK);
 use strict;
 
-# Object preamble - inherits from Bio::DB::RandomAccessI
+# Object preamble - inherits from Bio::DB::Abstract
 
-use Bio::DB::RandomAccessI;
+use Bio::DB::BioSeqI;
 use Bio::Seq;
 
 BEGIN { 
@@ -101,15 +101,16 @@ BEGIN {
 }
 
 
-@ISA = qw(Bio::DB::RandomAccessI);
+@ISA = qw(Bio::DB::BioSeqI Bio::Root::Object Exporter);
+@EXPORT_OK = qw();
 
 # new() is inherited from Bio::DB::Abstract
 
 # _initialize is where the heavy stuff will happen when new is called
 
-sub new {
-  my($class,@args) = @_;
-  my $self = $class->SUPER::new(@args);
+sub _initialize {
+  my($self,@args) = @_;
+  my $make = $self->SUPER::_initialize;
   my ($host,$port) = $self->_rearrange([qw(
 					 HOST
 					 PORT
@@ -128,7 +129,7 @@ sub new {
   $self->_aceobj($aceobj);
 
 
-  return $self;
+  return $make; # success - we hope!
 }
 
 =head2 get_Seq_by_id
@@ -189,7 +190,7 @@ sub get_Seq_by_acc {
   Args    : New value of the ace object
 
 =cut
-
+  
 sub _aceobj {
   my ($self,$arg) = @_;
 
@@ -201,9 +202,3 @@ sub _aceobj {
 }
 
 1;
-
-
-
-
-
-
