@@ -4,7 +4,7 @@
 #           many different modules and scripts.
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : 3 Sep 1996
-# REVISION: $Id: Global.pm,v 1.7 2000/07/12 17:46:59 dag Exp $
+# REVISION: $Id: Global.pm,v 1.4 1999/04/06 11:14:11 sac Exp $
 #
 # INSTALLATION:
 #   This module is included with the central Bioperl distribution:
@@ -28,40 +28,7 @@
 #    sac --- Fri 5 Jun 1998: Added @DAYS.
 #    sac --- Sun Aug 16 1998: Added $RECORD_ERR and &record_err().
 #--------------------------------------------------------------------------------
-
-### POD Documentation:
-
-=head1 NAME
-
-Bio::Root::Global - Global variables and utility functions
-
-=head1 SYNOPSIS
-
-    # no real synopsis - see Bio::Root::Object
-
-=head1 DESCRIPTION
-
-The Bio::Root::Global file contains all the global flags
-about erro warning etc, and also utility functions, eg
-to map numbers to roman numerals.
-
-These functions are generally called by Bio::Root::Object
-or somewhere similar, and not directly
-
-
-=head1 INSTALLATION
-
-This module is included with the central Bioperl distribution:
-
-   http://bio.perl.org/Core/Latest
-   ftp://bio.perl.org/pub/DIST
-
-Follow the installation instructions included in the README file.
-
-=cut
-
 package	 Bio::Root::Global;
-use strict;
 
 BEGIN {
     use vars qw($CGI $TIMEOUT_SECS);
@@ -76,7 +43,6 @@ BEGIN {
 use Exporter ();
 use vars qw($BASE_YEAR @DAYS @MONTHS);
 
-use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
 @ISA       = qw( Exporter );
 @EXPORT_OK = qw($AUTHORITY $NEWLINE
 		$DEBUG $MONITOR $TESTING 
@@ -118,10 +84,6 @@ use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
 ##             Data                 ##
 ######################################
 
-use vars qw($AUTHORITY $DEBUG $MONITOR $TESTING $DONT_WARN $WARN_ON_FATAL
-            $FATAL_ON_WARN $RECORD_ERR $STRICTNESS $VERBOSITY $NEWLINE
-            %ROMAN_NUMS $GLOBAL);
-
 # Who should receive feedback from users and possibly automatic error messages.
 $AUTHORITY     = 'sac@genome.stanford.edu';
  
@@ -253,9 +215,3 @@ sub fatal_on_warn {
 #####################################################################################
 
 1;
-
-
-
-
-
-
