@@ -3,7 +3,7 @@
 # PURPOSE : Provides general-purpose utilities of potential interest to any Perl script.
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : Feb 1996
-# REVISION: $Id: Utilities.pm,v 1.13.2.3 2001/11/02 18:58:18 jason Exp $
+# REVISION: $Id: Utilities.pm,v 1.5 1999/04/06 11:14:15 sac Exp $
 # STATUS  : Alpha
 #
 # This module manages file compression and uncompression using gzip or
@@ -14,7 +14,7 @@
 #
 # If you manage to incorporate an alternate compression utility into this
 # module, please post a note to the bio.perl.org mailing list
-# bioperl-l@bioperl.org
+# vsns-bcd-perl@lists.uni-bielefeld.de. Thanks.
 #
 # TODO    : Configure $GNU_PATH during installation.
 #           Improve documentation (POD).
@@ -22,14 +22,13 @@
 #
 # MODIFICATIONS: See bottom of file.
 #
-# Copyright (c) 1996-2000 Steve A. Chervitz. All Rights Reserved.
+# Copyright (c) 1996-8 Steve A. Chervitz. All Rights Reserved.
 #          This module is free software; you can redistribute it and/or 
 #          modify it under the same terms as Perl itself.
 #
 #-----------------------------------------------------------------------------
 
 package	Bio::Root::Utilities;
-use strict;
 
 use Bio::Root::Global  qw(:data :std $TIMEOUT_SECS);
 use Bio::Root::Object  ();
@@ -38,16 +37,16 @@ use POSIX;
 #use AutoLoader;
 #*AUTOLOAD = \&AutoLoader::AUTOLOAD;
 
-use vars qw( @ISA @EXPORT_OK %EXPORT_TAGS );
-@ISA         = qw( Bio::Root::RootI Exporter);
+@ISA         = qw( Bio::Root::Object Exporter);
 @EXPORT_OK   = qw($Util);
 %EXPORT_TAGS = ( obj => [qw($Util)],
 		 std => [qw($Util)],);
 
-use vars qw($ID $version $Util $GNU_PATH $DEFAULT_NEWLINE);
+use strict;  
+use vars qw($ID $VERSION $Util $GNU_PATH);
 
 $ID        = 'Bio::Root::Utilities';
-$version   = 0.05;
+$VERSION   = 0.042;
 
 # $GNU_PATH points to the directory containing the gzip and gunzip 
 # executables. It may be required for executing gzip/gunzip 
@@ -57,8 +56,6 @@ $version   = 0.05;
 $GNU_PATH  = ''; 
 #$GNU_PATH  = '/tools/gnu/bin/'; 
 
-$DEFAULT_NEWLINE = "\012";  # \n  (used if get_newline() fails for some reason)
-
 ## Static UTIL object.
 $Util = {};
 bless $Util, $ID;
@@ -131,8 +128,9 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org             - General discussion
-  http://bioperl.org/MailList.shtml - About the mailing lists
+    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
+    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
+    http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -185,9 +183,10 @@ for documentation purposes only.
 =cut
 
 
-############################################################################
-##                 INSTANCE METHODS                                       ##
-############################################################################
+##########################################################################################
+##                               INSTANCE METHODS                                       ##
+##########################################################################################
+
 
 =head2 date_format
 
@@ -230,7 +229,7 @@ for documentation purposes only.
            :           12/1/97 (for 1 December 1997)
            :           1997-12-01 
            :           1997-Dec-01
- Throws    : 
+ Throws    : Exception if the file appears to be empty or non-existent
  Comments  : Relies on the $BASE_YEAR constant exported by Bio:Root::Global.pm.
            :
            : If you don't care about formatting or using backticks, you can
@@ -243,7 +242,7 @@ See Also   : L<file_date>(), L<month2num>()
 
 =cut
 
-#---------------'
+#---------------
 sub date_format {
 #---------------
     my $self   = shift;
@@ -258,7 +257,7 @@ sub date_format {
     my (@date);
 
     # Load a supplied date for conversion:
-    if(defined($date) && ($date =~ /[\D-]+/)) {
+    if(defined($date)) {
 	if( $date =~ /\//) {
 	    ($mon,$mday,$year) = split(/\//, $date); 
 	} elsif($date =~ /(\d{4})-(\d{1,2})-(\d{1,2})/) {
@@ -272,8 +271,7 @@ sub date_format {
 	if(length($year) == 4) { $year = substr $year, 2; }
 	$mon -= 1;
     } else {
-	($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @date =
-	    localtime(($date ? $date : time()));
+	($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @date =localtime(time);
 	return @date if $option =~ /list/i;
     }
     $month_txt = $MONTHS[$mon];
@@ -332,9 +330,7 @@ sub date_format {
 
 =cut
 
-#--------------'
 sub month2num {
-#--------------
 
     my ($self, $str) = @_;
 
@@ -442,7 +438,7 @@ sub compress {
 
  Title     : uncompress
  Usage     : $Util->uncompress(filename, [tmp]);
- Purpose   : Uncompress a file.
+ Purpose   : Uncompress a file to conserve disk space.
  Example   : $Util->uncompress("/usr/people/me/data.txt.gz");
  Returns   : String (name of uncompressed file, full path).
  Argument  : filename = String (name of file to be uncompressed, full path).
@@ -523,7 +519,11 @@ sub uncompress {
           : date_format = string, desired format for date (see date_format()).
           :               Default = yyyy-mm-dd
  Thows    : Exception if no file is provided or does not exist.
- Comments : Uses the mtime field as obtained by stat().
+ Comments : Uses `ls -lga` to get file date data.
+          : Not so universal and not taint-safe. 
+          : Think about using stat() or a standard CPAN module for this, like
+          : Date::Manip or Date::DateCalc. However, these are pretty heavy-duty.
+          : I just want a simple function.
 
 =cut
 
@@ -535,9 +535,32 @@ sub file_date {
     $self->throw("No such file: $file") if not $file or not -e $file;
 
     $fmt ||= 'yyyy-mm-dd';
+    my($fmon,$fday,$fyear);
 
-    my @file_data = stat($file);
-    return $self->date_format($fmt, $file_data[9]); # mtime field
+    my $file_data = `ls -lga $file`;
+    # Parsing lines such as:
+    # -rwxr-xr-x   1 sac      sac          7028 Nov  5  1997 ./YDR222W.blastp
+    # -rwxrwxr-x   1 sac      sac           525 Jun 23 16:20 ./utilities.p
+    if($file_data =~ / ([a-z]{3})  ?([\d]{1,2})  ?([\d:]+) /i) {
+	($fmon,$fday,$fyear) = ($1, $2, $3);
+    } else {
+	# If the regexp fails, split().
+	my @file_data = split /\s+/, $file_data;
+	($fmon,$fday,$fyear) = @file_data[5..7];
+    }
+
+    if($fyear =~ /:/) { $fyear = $self->date_format('year'); }
+    my $fmon_num = '00';
+    foreach(0..11) { if($MONTHS[$_] eq $fmon) {$fmon_num = $_ + 1; last;} }
+
+    my $date = sprintf "%4d-%02d-%02d",$fyear,$fmon_num,$fday;
+
+    if($fmt =~ /yyyy-mmm-dd/i ) {
+	$date = sprintf "%4d-%3s-%02d",$fyear,$fmon,$fday;
+    } elsif($fmt eq 'd m y' ) {
+	$date = sprintf "%s %s %s",$fday,$fmon,$fyear;
+    }
+    $date;
 }
 
 
@@ -564,7 +587,7 @@ sub file_date {
 
 =cut
 
-#------------`
+#------------	
 sub untaint {
 #------------	
     my($self,$value,$relax) = @_;
@@ -592,6 +615,32 @@ sub untaint {
 }
 
 
+=head2 is_tainted
+
+ Title  : is_tainted
+ Purpose: Test whether a variable is tainted or not.
+        : Used for testing variables for taintedness. 
+        : Development use only. 
+ Usage  : $Util->is_tainted($string);
+ Warning: This method  always generates a compile-time
+        : warning and is therefore commented out.
+
+=cut
+
+#--------------
+sub is_tainted {
+#--------------
+#    my $self = shift;
+#    local($^W) = 0;    ## disable warnings with -w (run-time only)
+#    # Test for tained data. See the Camel book 2ed, p.358.
+#    not eval {
+#	  join("",@_), kill 0;
+#	  1;
+#    };
+}
+
+
+
 =head2 mean_stdev
 
  Title    : mean_stdev
@@ -756,7 +805,7 @@ sub delete {
            : this method should probably have a -mode parameter to
            : specify ascii or binary.
 
-See Also :  L<get_newline>(), L<Bio::Root::IOManager::read>(),
+See Also :  L<get_newline>(), L<Bio::Root:IOManager::read>(),
 
 =cut
 
@@ -767,7 +816,7 @@ sub create_filehandle {
     my($client, $file, $handle) =
 	$self->_rearrange([qw( CLIENT FILE HANDLE )], @param);
 
-    if(not ref $client) {  $client = $self; }
+    if(not $client) {  $client = $self; }
     $file ||= $handle;
     $file = $client->file($file);
 
@@ -780,6 +829,7 @@ sub create_filehandle {
 	$FH = $file;
 	$client->{'_input_type'} = "FileHandle";
       } elsif($handle_ref eq 'GLOB') {
+#	$FH = new FileHandle($file);  # Can't do this
 	$FH = $file;
 	$client->{'_input_type'} = "Glob";
       } else {
@@ -838,11 +888,12 @@ sub get_newline {
 
     my $FH = $self->create_filehandle(@param);
 
-    if(not ref $client) {  $client = $self;   }
+    if(not $client) {  $client = $self;   }
 
-    if($client->{'_input_type'} =~ /STDIN|Glob|compressed/) {
+    if($client->{'_input_type'} eq 'STDIN' ||
+      $client->{'_input_type'} =~ /compressed/ ) {
       # Can't taste from STDIN since we can't seek 0 on it.
-      # Are other non special Glob refs seek-able? 
+      # Are other non special Glob refs seek able?
       # Attempt to guess newline based on platform.
       # Not robust since we could be reading Unix files on a Mac, e.g.
       if(defined $ENV{'MACPERL'}) {
@@ -854,13 +905,11 @@ sub get_newline {
       $NEWLINE = $self->taste_file($FH);
     }
 
-    close ($FH) unless ($client->{'_input_type'} eq 'STDIN' || 
-                        $client->{'_input_type'} eq 'FileHandle' ||
-                        $client->{'_input_type'} eq 'Glob' );
+    close ($FH) unless $client->{'_input_type'} eq 'STDIN';
     
     delete $client->{'_input_type'};
 
-    return $NEWLINE || $DEFAULT_NEWLINE;
+    return $NEWLINE;
   }
 
 
@@ -895,24 +944,12 @@ sub taste_file {
   ref($FH) eq 'FileHandle' or $self->throw("Can't taste file: not a FileHandle ref");
 
   $buffer = '';
-
-  # this is a quick hack to check for availability of alarm(); just copied
-  # from Bio/Root/IOManager.pm HL 02/19/01
-  my $alarm_available = 1;
-  eval {
-      alarm(0);
-  };
-  if($@) {
-      # alarm() not available (ActiveState perl for win32 doesn't have it.
-      # See jitterbug PR#98)
-      $alarm_available = 0;
-  }
   $SIG{ALRM} = sub { die "Timed out!"; };
   my $result;
   eval {
-    $alarm_available && alarm( $wait );
+    alarm( $wait );
     $result = read($FH, $buffer, $BUFSIZ); # read the $BUFSIZ characters of file
-    $alarm_available && alarm(0);
+    alarm(0);
   };
   if($@ =~ /Timed out!/) {
     $self->throw("Timed out while waiting for input.", 
@@ -1014,7 +1051,7 @@ See Also  : L<mail_authority>()
 =cut
 
 
-#-------------'
+#-------------
 sub send_mail {
 #-------------
     my( $self, @param) = @_;
