@@ -1,3 +1,4 @@
+
 #
 # BioPerl module for Bio::Tools::AlignFactory
 #
@@ -32,27 +33,30 @@ The rest of the documentation details each of the object methods. Internal metho
 
 =cut
 
+
 # Let the code begin...
 
+
 package Bio::Tools::AlignFactory;
-use vars qw(@ISA);
+use vars qw($AUTOLOAD @ISA);
 use strict;
 
-# Object preamble - inherits from Bio::Root::Object
+# Object preamble - inheriets from Bio::Root::Object
 
 use Bio::Root::Object;
 
 BEGIN {
     eval {
-	require Bio::Ext::Align;
+	require bp_sw;
     };
     if ( $@ ) {
-	print STDERR ("\nThe C-compiled engine for Smith Waterman alignments (Bio::Ext::Align) has not been installed.\n Please install the bioperl-ext package\n\n");
+	print STDERR ("\nThe C-compiled engine for Smith Waterman alignments (bp_sw) has not been installed.\n Please read the installation instructions for bioperl for using the compiled extensions\n\n");
 	exit(1);
     }
 }
 
-@ISA = qw(Bio::Root::Object);
+
+@ISA = qw(Bio::Root::Object Exporter);
 # new() is inherited from Bio::Root::Object
 
 # _initialize is where the heavy stuff will happen when new is called
@@ -69,6 +73,7 @@ sub _initialize {
  return $make; # success - we hope!
 }
 
+
 =head2 kbyte
 
  Title     : kbyte()
@@ -91,6 +96,7 @@ sub kbyte {
     return $self->{'kbyte'};
 }
 
+
 =head2 report
 
  Title     : report()
@@ -126,6 +132,7 @@ sub report {
  Returns : 
  Args    :
 
+
 =cut
 
 sub set_memory_and_report{
@@ -135,12 +142,14 @@ sub set_memory_and_report{
        $self->throw("You can suggest aligning things with less than 5kb");
    }
 
-   &Bio::Ext::Align::change_max_BaseMatrix_kbytes($self->{'kbyte'});
+   &bp_sw::change_max_BaseMatrix_kbytes($self->{'kbyte'});
 
    if( $self->{'report'} == 0 ) {
-       &Bio::Ext::Align::error_off(16);
+       &bp_sw::error_off(16);
    } else {
-       &Bio::Ext::Align::error_on(16);
+       &bp_sw::error_on(16);
    }
 }
 
+
+
