@@ -3,7 +3,7 @@
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : March 1996
 # STATUS  : Alpha
-# REVISION: $Id: HSP.pm,v 1.11.2.2 2001/06/18 12:41:54 heikki Exp $
+# REVISION: $Id: HSP.pm,v 1.5 1999/03/15 11:14:57 sac Exp $
 #
 # For the latest version and documentation, visit the distribution site:
 #    http://genome-www.stanford.edu/perlOOP/bioperl/blast/
@@ -11,7 +11,7 @@
 # To generate documentation, run this module through pod2html
 # (preferably from Perl v5.004 or better).
 #
-# Copyright (c) 1996-2000 Steve A. Chervitz. All Rights Reserved.
+# Copyright (c) 1996-98 Steve A. Chervitz. All Rights Reserved.
 #           This module is free software; you can redistribute it and/or 
 #           modify it under the same terms as Perl itself.
 #----------------------------------------------------------------------------
@@ -25,13 +25,14 @@ use Bio::Root::Object ();
 @ISA = qw( Bio::Root::Object);  
 
 use strict;
-use vars qw($ID $GAP_SYMBOL @SCORE_CUTOFFS $Revision %STRAND_SYMBOL);
+use vars qw($ID $VERSION $GAP_SYMBOL @SCORE_CUTOFFS $Revision);
 $ID       = 'Bio::Tools::Blast::HSP';
-$Revision = '$Id: HSP.pm,v 1.11.2.2 2001/06/18 12:41:54 heikki Exp $';  #'
+$VERSION  = 0.080;
+$Revision = '$Id: HSP.pm,v 1.5 1999/03/15 11:14:57 sac Exp $';  #'
 
 $GAP_SYMBOL    = '-';          # Need a more general way to handle gap symbols.
 @SCORE_CUTOFFS = ( 100, 30 );  # Bit score cutoffs (see homol_score()).
-%STRAND_SYMBOL = ('Plus' => 1, 'Minus' => -1);
+
 
 ## POD Documentation:
 
@@ -48,7 +49,7 @@ You should not need to use this package directly. See L<_initialize>()
 for a description of constructor parameters.
 
     require Bio::Tools::Blast::HSP;
-
+ 
     $hspObj = eval{ new Bio::Tools::Blast::HSP(-DATA    =>\@hspData, 
 					       -PARENT  =>$sbjct_object, 
 					       -NAME    =>$hspCount,
@@ -85,49 +86,47 @@ HSP objects (L<Links:>).
 
 =back
 
-Bio::Tools::Blast::HSP.pm has the ability to extract a list of all
-residue indices for identical and conservative matches along both
-query and sbjct sequences. Since this degree of detail is not always
-needed, this behavior does not occur during construction of the HSP
-object.  These data will automatically be collected as necessary as
-the HSP.pm object is used.
+Bio::Tools::Blast::HSP.pm has the ability to extract a list of all residue 
+indices for identical and conservative matches along both query and
+sbjct sequences. Since this degree of detail is not always needed, 
+this behavior does not occur during construction of the HSP object.
+These data will automatically be collected as necessary as the 
+HSP.pm object is used.
 
 =head1 DEPENDENCIES
 
-Bio::Tools::Blast::HSP.pm is a concrete class that inherits from
-B<Bio::Root::Object.pm> and relies on B<Bio::Tools::Sbjct.pm> as a
-container for HSP.pm objects.  B<Bio::Seq.pm> and B<Bio::UnivAln.pm>
-are employed for creating sequence and alignment objects,
-respectively.
+Bio::Tools::Blast::HSP.pm is a concrete class that inherits from B<Bio::Root::Object.pm>
+and relies on B<Bio::Tools::Sbjct.pm> as a container for HSP.pm objects.
+B<Bio::Seq.pm> and B<Bio::UnivAln.pm> are employed for creating sequence
+and alignment objects, respectively.
 
 
 =head2 Relationship to UnivAln.pm & Seq.pm
 
-HSP.pm can provide the query or sbjct sequence as a B<Bio::Seq.pm>
-object via the L<seq>() method. The HSP.pm object can also create a
-two-sequence B<Bio::UnivAln.pm> alignment object using the the query
-and sbjct sequences via the L<get_aln>() method. Creation of alignment
-objects is not automatic when constructing the HSP.pm object since
-this level of functionality is not always required and would generate
-a lot of extra overhead when crunching many reports.
+HSP.pm can provide the query or sbjct sequence as a B<Bio::Seq.pm> object
+via the L<seq>() method. The HSP.pm object can also create a two-sequence 
+B<Bio::UnivAln.pm> alignment object using the the query and sbjct sequences 
+via the L<get_aln>() method. Creation of alignment objects is not automatic when
+constructing the HSP.pm object since this level of functionality is not always
+required and would generate a lot of extra overhead when crunching many reports.
 
 
 =head1 FEEDBACK
 
 =head2 Mailing Lists 
 
-User feedback is an integral part of the evolution of this and other
-Bioperl modules.  Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other Bioperl modules.
+Send your comments and suggestions preferably to one of the Bioperl mailing lists.
+Your participation is much appreciated.
 
-    bioperl-l@bioperl.org          - General discussion
+    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
+    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
     http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track the bugs and 
+their resolution. Bug reports can be submitted via email or the web:
 
     bioperl-bugs@bio.perl.org                   
     http://bio.perl.org/bioperl-bugs/           
@@ -136,6 +135,10 @@ or the web:
 
 Steve A. Chervitz, sac@genome.stanford.edu
 
+=head1 VERSION
+
+Bio::Tools::Blast::HSP.pm, 0.080
+
 =head1 SEE ALSO
 
  Bio::Tools::Blast::Sbjct.pm   - Blast hit object.
@@ -144,7 +147,7 @@ Steve A. Chervitz, sac@genome.stanford.edu
  Bio::UnivAln.pm               - Biosequence alignment object.
  Bio::Root::Object.pm          - Proposed base class for all Bioperl objects.
 
-=head2 Links:
+Links:
 
  http://bio.perl.org/Core/POD/Tools/Blast/Sbjct.pm.html
 
@@ -295,7 +298,7 @@ sub _set_data {
     # Storing the match list in case it is needed later.
     $self->{'_matchList'} = \@matchList;
 
-    if(not defined ($self->{'_numIdentical'})) {
+    if(!$self->{'_numIdentical'}) {
       $self->throw("Can't parse match statistics.",
 		   "Possibly a new or unrecognized Blast format.");
     }
@@ -331,26 +334,26 @@ sub _set_score_stats {
 
     my ($expect, $p);
 
-    if($data =~ /Score = +([\d.e+-]+) bits \(([\d.e+-]+)\), +Expect = +([\d.e+-]+)/) {
+    if($data =~ /Score = +([\d.e+]+) bits \(([\d.e+]+)\), +Expect = +([\d.e+-]+)/) {
 	# blast2 format n = 1
 	$self->{'_bits'}   = $1;
 	$self->{'_score'}  = $2;
 	$expect            = $3;
-    } elsif($data =~ /Score = +([\d.e+-]+) bits \(([\d.e+-]+)\), +Expect\((\d+)\) = +([\d.e+-]+)/) {
+    } elsif($data =~ /Score = +([\d.e+]+) bits \(([\d.e+]+)\), +Expect\((\d+)\) = +([\d.e+-]+)/) {
 	# blast2 format n > 1
 	$self->{'_bits'}   = $1;
 	$self->{'_score'}  = $2;
 	$self->{'_n'}      = $3;
 	$expect            = $4;
 
-    } elsif($data =~ /Score = +([\d.e+-]+) \(([\d.e+-]+) bits\), +Expect = +([\d.e+-]+), P = +([\d.e-]+)/) {
+    } elsif($data =~ /Score = +([\d.e+]+) \(([\d.e+]+) bits\), +Expect = +([\d.e+-]+), P = +([\d.e-]+)/) {
 	# blast1 format, n = 1
 	$self->{'_score'}  = $1;
 	$self->{'_bits'}   = $2;
 	$expect            = $3;
 	$p                 = $4;
 
-    } elsif($data =~ /Score = +([\d.e+-]+) \(([\d.e+-]+) bits\), +Expect = +([\d.e+-]+), +Sum P\((\d+)\) = +([\d.e-]+)/) {
+    } elsif($data =~ /Score = +([\d.e+]+) \(([\d.e+]+) bits\), +Expect = +([\d.e+-]+), +Sum P\((\d+)\) = +([\d.e-]+)/) {
 	# blast1 format, n > 1
 	$self->{'_score'}  = $1;
 	$self->{'_bits'}   = $2;
@@ -1253,14 +1256,13 @@ sub end {
  Purpose   : Get the strand of the query or sbjct sequence.
  Example   : print $hsp->strand('query');
            : ($qstrand, $sstrand) = $hsp->strand();
- Returns   : -1, 0, or 1
-           : -1 = Minus strand, +1 = Plus strand
-           : Returns 0 if strand is not defined, which occurs
-           : for non-TBLASTN/X reports.
-           : In scalar context without arguments, returns queryStrand value.
+ Returns   : string: 'Minus' or 'Plus'
+           : In scalar context without arguments, returns queryStrand.
            : In array context without arguments, returns a two-element list 
            :    of strings (queryStrand, sbjctStrand).
            : Array context can be "induced" by providing an argument of 'list' or 'array'.
+           : Returns null string(s) if strand is not defined, which occurs
+           : for non-TBLASTN/X reports.
  Argument  : seq_type: 'query' | 'sbjct' or undef
  Throws    : n/a
 
@@ -1286,8 +1288,7 @@ sub strand {
 	return ('','') unless defined $self->{'_queryStrand'};
 	return ($self->{'_queryStrand'}, $self->{'_sbjctStrand'});
     }
-    local $^W = 0;
-    $STRAND_SYMBOL{$self->{$seqType.'Strand'}} || 0;
+    $self->{$seqType.'Strand'} || '';
 }
 
 
@@ -1506,7 +1507,7 @@ sub display {
 #-----------
     my( $self, %param ) = @_;
     
-     my $sbjctName = $self->parent->name();
+    my $sbjctName = $self->parent->name();
     my $queryName = $self->parent->parent->name();
     my $layout = $self->parent->parent->_layout();
     
@@ -1525,13 +1526,10 @@ sub display {
     } else {
 	printf( $OUT "%-15s: %.1e\n", "EXPECT", $self->{'_expect'} );
     }
-
-    my $queryLength = $self->length('query'); 
-
     printf( $OUT "%-15s: %d (%0.0f%%)\n", "IDENTICAL", $self->{'_numIdentical'}, 
-	   $self->{'_numIdentical'}/$queryLength * 100 );
+	   $self->{'_numIdentical'}/$self->{'_length'}*100 );
     printf( $OUT "%-15s: %d (%0.0f%%)  %s \n", "CONSERVED", $self->{'_numConserved'}, 
-	   $self->{'_numConserved'}/$queryLength * 100,
+	   $self->{'_numConserved'}/$self->{'_length'}*100,
 	   "includes identical" );
     
     $self->_display_seq('query', $queryName, $OUT);
