@@ -4,7 +4,7 @@
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu).
 # CREATED : 22 May 1998
 # STATUS  : STUB MODULE, MUST BE CUSTOMIZED FOR A LOCAL SITE.
-# REVISION: $Id: LocalBlast.pm,v 1.5.2.2 2001/06/21 15:36:05 heikki Exp $
+# REVISION: $Id: LocalBlast.pm,v 1.1.1.1 1998/12/11 15:24:24 birney Exp $
 #
 # For the latest version and documentation, visit the distribution site:
 #    http://genome-www.stanford.edu/perlOOP/bioperl/blast/
@@ -18,15 +18,12 @@
 #-------------------------------------------------------------------------------
 
 package Bio::Tools::Blast::Run::LocalBlast;
-use strict;
 
 use Bio::Root::Object    qw(&_rearrange);
 use Bio::Root::Global    qw(:devel);
 use Bio::Root::Utilities qw(:obj);
 use Carp;
 
-use Exporter;
-use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 @ISA        = qw(Exporter);
 @EXPORT     = qw();
 @EXPORT_OK  = qw(&blast_local @Blast_dbp_local @Blast_dbn_local 
@@ -35,18 +32,17 @@ use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 		 @Blast_matrix_local)] );
 
 use strict;
-use vars qw( $ID $version);
+use vars qw( $ID $VERSION);
 
 $ID      = 'Bio::Tools::Blast::Run::LocalBlast';
-$version = '0.01';
+$VERSION = '0.01';
 
 
 ## POD Documentation
 
 =head1 NAME
 
-Bio::Tools::Blast::Run::LocalBlast.pm - Bioperl module for running
-Blast analyses locally.
+Bio::Tools::Blast::Run::LocalBlast.pm - Bioperl module for running Blast analyses locally.
 
 =head1 SYNOPSIS
 
@@ -67,9 +63,9 @@ Follow the installation instructions included in the README file.
 
 =head1 DESCRIPTION
 
-Bio::Tools::Blast::Run::LocalBlast.pm contains methods and data
-necessary for running Blast sequence analyses on a local machine. This
-module must be customized for a specific site.
+Bio::Tools::Blast::Run::LocalBlast.pm contains methods and data necessary for
+running Blast sequence analyses on a local machine. This module must be customized
+for a specific site.
 
 The basic requirements are that it conform to this minimal API:
 
@@ -77,31 +73,29 @@ The basic requirements are that it conform to this minimal API:
 
 =item 1 Export a method called L<blast_local>()
 
-that accepts a Bio::Tools::Blast.pm object + named parameters as
-specified by L<blast_local>().
+that accepts a Bio::Tools::Blast.pm object + named parameters as specified by L<blast_local>().
 
 =item 2 The L<blast_local>() method should return 
 
 a list of names of files containing the raw Blast reports.
 
-=item 3 Exporting arrays containing a list of available databases 
+=item 3 Export arrays containing a list of available databases 
 
 in the arrays C<@Blast_dbn_local> and C<@Blast_dbp_local>.
 
 =back
 
-The generic version of this module provides some rudimentary logic,
-but feel free to customize as necessary.
+The generic version of this module provides some rudimentary logic, but feel free
+to customize as necessary.
 
 
 =head2 Script Files
 
-Sometimes it is convenient to write an executable shell script for
-running a set of Blasts on a local machine. This script can be saved
-and re-executed as necessary or saved for documentation purposes. This
-module could provide a convenient way to consolidate the logic
-necessary for producing such script files or perhaps stubs of script
-file that could be further modified for Blast-ing specific datasets.
+Sometimes it is convenient to write an executable shell script for running a set of Blasts
+on a local machine. This script can be saved and re-executed as necessary or saved
+for documentation purposes. This module could provide a convenient way to consolidate
+the logic necessary for producing such script files or perhaps stubs of script file 
+that could be further modified for Blast-ing specific datasets.
 
 
 =head1 DEPENDENCIES
@@ -127,18 +121,18 @@ be updated along with that module.
 
 =head2 Mailing Lists 
 
-User feedback is an integral part of the evolution of this and other
-Bioperl modules.  Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other Bioperl modules.
+Send your comments and suggestions preferably to one of the Bioperl mailing lists.
+Your participation is much appreciated.
 
-    bioperl-l@bioperl.org          - General discussion
+    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
+    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
     http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track the bugs and 
+their resolution. Bug reports can be submitted via email or the web:
 
     bioperl-bugs@bio.perl.org                   
     http://bio.perl.org/bioperl-bugs/           
