@@ -1,17 +1,16 @@
 #--------------------------------------------------------------------
 # PACKAGE : Bio::Tools::Blast::Run::Webblast.pm
-# PURPOSE : To run a Blast analysis on a remote server 
+# PURPOSE : To run a Blast analysis on an NCBI server 
 #           and save the results locally.
-# AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu) 
-#               - Webblast.pm: modularized version of webblast.
-#           Alex Dong Li (ali@genet.sickkids.on.ca) 
-#               - original webblast script.
+# AUTHOR  : Alex Dong Li (ali@genet.sickkids.on.ca) 
+#               - original webblast version.
+#           Steve A. Chervitz (sac@genome.stanford.edu) 
+#               - this modularized version.
 #           Ross N. Crowhurst (RCrowhurst@hort.cri.nz)
-#               - modified Webblast.pm to use LWP to give proxy server 
-#                 support.
+#               - modified to use LWP to give proxy server support
 # CREATED : 4 May 1998
 # STATUS  : Alpha
-# REVISION: $Id: Webblast.pm,v 1.8.2.4 2001/06/21 15:36:05 heikki Exp $
+# REVISION: $Id: Webblast.pm,v 1.4 1999/04/25 08:33:24 sac Exp $
 #
 # For documentation, run this module through pod2html
 # (preferably from Perl v5.004 or better).
@@ -25,7 +24,6 @@
 #------------------------------------------------------------------------
 
 package Bio::Tools::Blast::Run::Webblast;
-use strict;
 
 # rnc: now uses HTTP and LWP.
 # sac: Make sure HTTP and LWP are available.
@@ -34,7 +32,7 @@ use strict;
 #      still be examined. Dieing only if blast_remote() is attempted.
 
 BEGIN {
-  use vars qw($Loaded_LWP $Loaded_IOScalar);
+  use vars qw($Loaded_LWP);
   $Loaded_LWP = 1;
   unless( eval "require HTTP::Request::Common" and
 	  eval "require LWP::UserAgent") {
@@ -47,28 +45,13 @@ BEGIN {
   }
 
   HTTP::Request::Common->import(qw(POST)) if $Loaded_LWP;
-
-  $Loaded_IOScalar = 1;
-  unless( eval "require IO::Scalar") {
-    warn "\a\n".'='x50, "\n".
-      "WARNING: COULDN'T LOAD THE IO::Scalar MODULE.\n\n".
-      "   IO::Scalar is now required to run remote Blasts.\n".
-      "   This module is included in the IO-stringy collection\n".
-      "   from CPAN: http://www.perl.com/CPAN/.".
-	"\n".'='x50, "\n\n";
-    $Loaded_IOScalar = 0;
-  }
 }
 
-use Bio::SeqIO;
 use Bio::Root::Global    qw(:devel);
 use Bio::Root::Utilities qw(:obj);
 use Bio::Tools::Blast::HTML qw(&strip_html);
-use IO::Scalar;
 use Carp;
 
-use Exporter;
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA        = qw(Exporter);
 @EXPORT     = qw();
 @EXPORT_OK  = qw(&blast_remote @Blast_dbp_remote @Blast_dbn_remote 
@@ -77,10 +60,10 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 			    @Blast_matrix_remote)] );
 
 use strict;
-use vars qw( $ID $version $revision);
+use vars qw( $ID $VERSION $revision);
 
 $ID       = 'Bio::Tools::Blast::Run::Webblast';
-$version  = 1.24; 
+$VERSION  = 1.2; 
 
 # SAC: grouped database names.
 # May want to put these sorts of things in a
@@ -117,12 +100,10 @@ my %_default = (
 		'minimumLengthProtein'  => 10,
 		'maximumLength'         => 100000, 
 		'maximumLengthProtein'  => 50000, 
-# Blast1 no longer supported at NCBI
-#		'blastServerURL1'       => 'www.ncbi.nlm.nih.gov/',
-		'blastServerURL2'       => 'www.ncbi.nlm.nih.gov/blast/blast.cgi',
-		'blastServerURLpsi'     => 'www.ncbi.nlm.nih.gov/blast/psiblast.cgi',
-		'blastServerURLphi'     => 'www.ncbi.nlm.nih.gov/blast/phiblast.cgi',
-		# rnc:	added WashU-Blast2 server address, ..WashU - first remote WashU Blast Server to use
+		'blastServerURL1'       => 'www.ncbi.nlm.nih.gov/cgi-bin/BLAST/nph-blast',
+		'blastServerURL2'       => 'www.ncbi.nlm.nih.gov/cgi-bin/BLAST/nph-newblast',
+		'blastServerURLpsi'     => 'www.ncbi.nlm.nih.gov/cgi-bin/BLAST/nph-psi_blast',
+		# rnc:	added WashU-Blast2 server address, ..WashU - first remote Wash-U Blast Server to use
 		# rnc:	added proxy server address option
 		'blastServerURLWashU'	=> 'www2.ebi.ac.uk/cgi-bin/newblast2.pl',
 		'entryServerURLroot'    => 'www.ncbi.nlm.nih.gov',
@@ -237,146 +218,6 @@ my $_errmsg                 = '';
 #$username    = join("", @username);
 
 
-
-## POD Documentation
-
-=head1 NAME
-
-Bio::Tools::Blast::Run::Webblast.pm - Bioperl module for running Blast analyses using a HTTP interface.
-
-=head1 SYNOPSIS
-
-    # Run a Blast
-    use Bio::Tools::Blast::Run::Webblast qw(&blast_remote);
-
-    @out_file_names = &blast_remote($object, %named_parameters);
-
-L<blast_remote> is the only exported method of this module
-and it returns a list of local file names containing the Blast
-reports. C<$object> is a reference to a B<Bio::Root::Object.pm> object or
-subclass. See L<blast_remote>() for a description of available parameters.
-
-    # Obtain a list of available databases
-
-    use Bio::Tools::Blast::Run::Webblast qw(@Blast_dbp_remote
-					    @Blast_dbn_remote);
-
-    @amino_dbs      = @Blast_dbp_remote;
-    @nucleotide_dbs = @Blast_dbn_remote;
-
-
-=head1 INSTALLATION
-
-This module is included with the central Bioperl distribution:
-
-   http://bio.perl.org/Core/Latest
-   ftp://bio.perl.org/pub/DIST
-
-Follow the installation instructions included in the README file.
-
-=head1 DESCRIPTION
-
-B<Bio::Tools::Blast::Run::Webblast.pm> contains methods and data necessary for
-running Blast sequence analyses using a remote server and saving the results locally.
-
-B<Bio::Tools::Blast::run()> provides an interface for Webblast.pm,
-so, ideally, you shouldn't use Webblast.pm directly, but via Blast.pm. 
-
-B<FEATURES:>
-
-=over 2
-
-=item * Supports NCBI Blast1, Blast2, and PSI-Blast servers as well as WashU-Blast servers.
-
-=item * Can operate through a proxy server enabling operation from behind a firewall.
-
-=item * Can save reports with and without HTML formatting.
-
-=item * Uses LWP.
-
-=back
-
-In principle, this module can be customized to use different servers
-that provide a Blast interface like the NCBI or WashU style servers. 
-Such servers could be remote or local. This hasn't been well-tested however. 
-
-
-=head1 DEPENDENCIES
-
-Bio::Tools::Blast::Run::Webblast.pm is used by B<Bio::Tools::Blast.pm>.
-The development of this is thus linked with the Blast.pm module.
-
-=head1 SEE ALSO
-
- Bio::Tools::Blast.pm                    - Blast object.
- Bio::Tools::Blast::Run::LocalBlast.pm   - Utility module for running Blasts locally.
- Bio::Tools::Blast::HTML.pm              - Blast HTML-formating utility class.
- Bio::Seq.pm                             - Biosequence object  
- Bio::Root::Object.pm                    - Bioperl base object class.
-
-
- http://bio.perl.org/Projects/modules.html  - Online module documentation
- http://bio.perl.org/Projects/Blast/        - Bioperl Blast Project     
- http://bio.perl.org/                       - Bioperl Project Homepage
-
-=head1 FEEDBACK
-
-=head2 Mailing Lists 
-
-User feedback is an integral part of the evolution of this and other
-Bioperl modules. Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
-
-  bioperl-l@bioperl.org                 - General discussion
-  http://bio.perl.org/MailList.html  - About the mailing lists
-
-=head2 Reporting Bugs
-
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
-
-  bioperl-bugs@bioperl.org
-  http://bio.perl.org/bioperl-bugs/
-
-=head1 AUTHOR
-
-=over 0
-
-=item Steve A. Chervitz E<lt>sac@genome.stanford.eduE<gt>
-
-    - Webblast.pm modularized version of webblast script.
-
-=item Alex Dong Li E<lt>ali@genet.sickkids.on.caE<gt>
-
-    - original webblast script.
-
-=item Ross N. Crowhurst E<lt>RCrowhurst@hort.cri.nzE<gt>
-
-    - modified Webblast.pm to use LWP to give proxy server support.
-
-=back 
-
-=head1 VERSION
-
-Bio::Tools::Blast::Run::Webblast.pm, 1.24
-
-=head1 COPYRIGHT
-
-Copyright (c) 1998, 1999 Steve A. Chervitz, Alex Dong Li,  Ross N. Crowhurst. 
-All Rights Reserved.This module is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-=cut
-
-#
-##
-###
-#### END of main POD documentation.
-###
-##
-#'
-
 ######################  BEGIN FUNCTIONS  ########################
 
 =head1 APPENDIX
@@ -392,9 +233,6 @@ for documentation purposes only.
  Usage     : @files = blast_remote( $blast_object,  %namedParameters);
            : This method is exported.
  Purpose   : Run a remote Blast analysis on one or more sequences.
-           : NOTE: The name of this method is potentially misleading
-           :       since the a local server could be specified.
-  	   :       Probably should be called blast_http.
  Returns   : Array containing a list of filenames of the Blast reports.
  Argument  : First argument should be a Bio::Tools::Blast.pm object reference.
            : This object is primarily used for error reporting
@@ -452,7 +290,7 @@ for documentation purposes only.
         nr, month, swissprot, dbest, dbsts, 
         est_mouse, est_human, est_others, pdb, vector, kabat,
         mito, alu, epd, yeast, ecoli, gss, htgs.
-
+ 
     These are exported by this module in the @Blast_dbp_remote
     and @Blast_dbn_remote arrays.
   -------------------------------------------------------------
@@ -465,7 +303,7 @@ for documentation purposes only.
         (11) Bacterial                  (12) Alternative Yeast Nuclear
         (13) Ascidian Mitochondrial     (14) Flatworm Mitochondrial
         (15) Blepharisma Macronuclear
-
+ 
   -------------------------------------------------------------
   Available values for organism (Blast2):
 
@@ -503,11 +341,11 @@ for documentation purposes only.
        4             flat master-slave without identities
  -------------------------------------------------------------
   Available substitution scoring matrices (NCBI):
-
+      
       BLAST2 matrices: BLOSUM80, BLOSUM62, BLOSUM45, PAM30, PAM70
 
       BLAST1 matrices: BLOSUM62, PAM40, PAM120, PAM250, IDENTITY.
-
+      
       Others members of the BLOSUM and PAM family of matrices
       may be available as well.
       These are exported by this module in the @Blast_matrix_remote array.
@@ -545,13 +383,6 @@ sub blast_remote {
 	     "   Download it from CPAN: http://www.perl.com/CPAN/.\n");
     }
 
-    unless ($Loaded_IOScalar) {
-      croak ("THE IO::Scalar MODULE IS NOT INSTALLED.\n\n".
-             "   IO::Scalar is now required to run remote Blasts.\n".
-             "   This module is included in the IO-stringy collection\n".
-             "   from CPAN: http://www.perl.com/CPAN/.");
-  }
-
     my ($seq_a);
     eval { 
 	# _rearrange() is an instance method of Bio::Root::Object.pm and is
@@ -639,7 +470,6 @@ sub _set_options {
     if($email)   { $resultReturnProtocol="email";
 		   $emailAddress = $email; }
     if($server)  { $blastServerURL = $server;}
-           else  { $blastServerURL = '';}
     if($minl)    { $minimumLength = $minl; } # if match minlength
     if($maxl)    { $maximumLength = $maxl; } # if match maxlength
     if($dir)     { $_out_dir = $dir; }
@@ -821,11 +651,7 @@ sub _blast {
 	    next unless &_validate_seq($seq);
 	    
 	    # add >seq_name to make seq in fasta format
-            my $sh = new_tie IO::Scalar \$sequenceInFastaFormat;
-            my $out = Bio::SeqIO->new ('-fh'   => $sh,   
-                                       '-format' =>'Fasta');
-
-            $out->write_seq($seq);
+	    $sequenceInFastaFormat= $seq->layout('Fasta');
 	    $sequenceInFastaFormat =~ s/\n$//;
 	    
 	    # concatenate advanced options into a string, depending on differnt blast type
@@ -842,7 +668,6 @@ sub _blast {
 	    
 	    # get temp filename and final filename
 	    $id = $seq->id;
-	    $id =~ s/[|:\/\\<>]/_/g;  # remove special chars that could confuse shell
 	    $id =~ s/\.\w+?$//;  # trim off the extension if id is a filename.
 	    $baseFileName = $_out_dir. $id . "." . $extension . "$version.$database"; # SAC: new var.
 	    $outputFileNameTemp = $baseFileName. ".temp.html";
@@ -955,7 +780,7 @@ sub _blast {
 		  
 		  # rnc:  formulate the request block - using 5 different blocks for blast versions
 		  #       -version 1, -version 2, and -version 3 recognised by bioPerl as well as 
-		  #       -version washu for default remote WashU Blast2, 
+		  #       -version washu for default remote Wash-U Blast2, 
 		  #       -version psi for PSI-Blast2 (PHI-Blast2 not yet supported).
 		  #	No doubt there is a better way to do this but this way is what my present
 		  #	experience with perl dictates I must use. It works this way if a bit ugly. 
@@ -1064,8 +889,8 @@ sub _blast {
 					  );
 		  }
 		  
-		  # rnc: POST block for WashU Blast to default WashU Blast2 remote server
-		  #	enables WashU Blast2 specific commands
+		  # rnc: POST block for Wash-U Blast to default Wash-U Blast2 remote server
+		  #	enables Wash-U Blast2 specific commands
 		  #	NOTE: the params here are not even remotely correct at present!
 		  if ($version =~ /wash|wu/i) {
 		      $req = &_get_request (
@@ -1141,11 +966,7 @@ sub _blast {
 			      if(-s $outputFileNameTemp) 
 				{
 				    $outFile = $outputFileNameTemp;
-# Updated for the operation of the NCBI queueing system
-# which now always results in the temporary file being saved.
-				    $MONITOR && print STDERR "Blast submission result saved to file $outputFileNameTemp\n"; 
-# Formerly, when the actual report was returned:
-#				    $MONITOR && print STDERR "Possibly bad Blast result saved to file $outputFileNameTemp\n"; 
+				    $MONITOR && print STDERR "Possibly bad Blast result saved to file $outputFileNameTemp\n"; 
 				} else {
 				    unlink $outputFileNameTemp;
 				    $MONITOR && print STDERR "No Blast results saved.\n";
@@ -1230,8 +1051,8 @@ sub _validate_seq {
 # Returns : zero if sequence length is too short or too long
 #           otherwise returns 1.
     my $seq = shift;
-    my $type = $seq->moltype;
-    my $len = $seq->length;
+    my $type = $seq->type;
+    my $len = $seq->seq_len;
 
     # Verify that sequence type is correct type for selected program.
     if( (defined $type and $type !~ /unknown/i) 
@@ -1371,10 +1192,6 @@ sub _removeJunkTagAndText {
    while (!eof(INPUT_FILE_FOR_REMOVE)) {
       $line=<INPUT_FILE_FOR_REMOVE>;
       # SAC: substituting in one step.
-      # rnc: not possible with PSI as it uses ACTION=.. for continuation of posting
-      #
-      # ACTION="/cgi-bin/BLAST" line added to get PSI to continue
-      $line =~ s|ACTION="/cgi-bin/BLAST|ACTION="http://$entryServerURLroot/cgi-bin/BLAST|;
       $line =~ s|<a href="/|<a href="http://$entryServerURLroot/|;
       print OUTPUT_FILE_FOR_REMOVE $line;
    }
@@ -1504,7 +1321,7 @@ sub _removeHTMLtags {
 
 ######################  Blast Variables  ########################
 
-=head1 APPENDIX 2: Parameter listings
+=head1 APPENDIX 1
 
 Parameters for Blast (NCBI ungapped, no longer supported by NCBI so
 should dicontinue use of ungapped blast), Blast2 (NCBI), PSI-Blast2
@@ -1733,17 +1550,17 @@ BLOSUM45	 19	 1
 BLOSUM45	 18	 1  
 BLOSUM45	 17	 1  
 BLOSUM45	 16	 1  
-
+ 
 OTHER_ADVANCED
 [default value]:""
-
+ 
 EMAIL
 [default value]:''
 IS_SET
 
 PATH
 [default value]:""
-
+ 
 HTML
 [default value]:''
 IS_SET
@@ -1841,14 +1658,13 @@ BLOSUM45	 19	 1
 BLOSUM45	 18	 1
 BLOSUM45	 17	 1
 BLOSUM45	 16	 1
-
+ 
 OTHER_ADVANCED
 [default value]:""
 
-=head2 WashU BLAST2
-
-WU-Blast2 Database Searches
+=head2 Wash-U BLAST2
 http://www2.ebi.ac.uk/blast2/
+WU-Blast2 Database Searches
 
 email
 ""
@@ -2022,21 +1838,6 @@ __END__
 ############################################################################
 
 # MODIFICATION HISTORY :
-#  1.24, 15 May 2000 sac:
-#     -- Uses SeqIO and IO::Scalar instead of Bio::Seq->layout()
-#        to get a Fasta-formatted sequence string.
-#     -- Removed message about possibly bad blast report
-#        which now always happens given the NCBI queueing system
-#
-#  1.23, 15 Oct 1999, sac:
-#     -- Updated the URLs for the NCBI servers.
-#
-#  1.22, 26 Jun 1999, sac:
-#      -- Bug fix in _blast(): Removing characters from temp file name 
-#         that could confuse shell (reported by Bradford Powell).
-#      -- Bug fix in _set_options() to reset the blastServerURL between
-#         invocations (reported by James Diggans).
-#      -- Added general POD for the module itself.
 #
 #  1.2, 20 Apr 1999, sac:
 #      -- Added support for new options introduced by RNC's modifications
@@ -2066,7 +1867,7 @@ __END__
 #		and used in the request as: NCBI_GI         =>      $NCBI_giOption,
 #       -- added several options to POST for BLAST2 which I am unsure are supported by
 #		bioperl (passed by it actually) as yet - help ? (see NCBI blast2 POST block)
-#       -- added a default WashU Blast2 server variable and set to 
+#       -- added a default Wash-U Blast2 server variable and set to 
 #		'blastServerURLWashA'	=> 'www2.ebi.ac.uk/cgi-bin/newblast2.pl',
 #       -- www2.ebi.ac.uk uses different parameter names in cgi script so probably 
 #		should look for a alternate one (an alternative could be 
