@@ -2,7 +2,7 @@
 # PACKAGE : Bio::Tools::SeqPattern.pm
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : 28 Aug 1997
-# REVISION: $Id: SeqPattern.pm,v 1.5.2.2 2001/06/21 15:36:05 heikki Exp $
+# REVISION: $Id: SeqPattern.pm,v 1.1.1.1 1998/12/11 15:24:23 birney Exp $
 #            
 # Copyright (c) 1997-8 Steve A. Chervitz. All Rights Reserved.
 #           This module is free software; you can redistribute it and/or 
@@ -11,12 +11,14 @@
 
 package Bio::Tools::SeqPattern;
 
-use Bio::Root::RootI;
-@ISA = qw(Bio::Root::RootI);
+use Bio::Root::Global qw(:devel);
+use Bio::Seq ();
+
+@ISA = qw(Bio::Seq);
 use strict;
-use vars qw ($ID $version);
+use vars qw ($ID $VERSION);
 $ID  = 'Bio::Tools::SeqPattern';
-$version = 0.011;
+$VERSION = 0.011;
 
 ## These constants may be more appropriate in a Bio::Dictionary.pm 
 ## type of class.
@@ -58,12 +60,10 @@ Follow the installation instructions included in the README file.
 
 =head1 DESCRIPTION
 
-The Bio::Tools::SeqPattern.pm module encapsulates generic data and
-methods for manipulating regular expressions describing nucleic or
-amino acid sequence patterns (a.k.a, "motifs").
+The Bio::Tools::SeqPattern.pm module encapsulates generic data and methods for manipulating 
+regular expressions describing nucleic or amino acid sequence patterns (a.k.a, "motifs").
 
-Bio::Tools::SeqPattern.pm is a concrete class that inherits from
-B<Bio::Seq.pm>.
+Bio::Tools::SeqPattern.pm is a concrete class that inherits from B<Bio::Seq.pm>.
 
 This class grew out of a need to have a standard module for doing routine
 tasks with sequence patterns such as:
@@ -74,7 +74,7 @@ tasks with sequence patterns such as:
   -- Untainting yet preserving special characters in the pattern
 
 Other features to look for in the future:
-
+ 
   -- Full pattern syntax checking
   -- Conversion between expanded and ondensed forms of the pattern
 
@@ -84,13 +84,13 @@ A key motivation for Bio::Tools::SeqPattern.pm is to have a way to
 generate a reverse complement of a nucleotide sequence pattern.
 This makes possible simultaneous pattern matching on both sense and 
 anti-sense strands of a query sequence. 
-
+ 
 In principle, one could do such a search more inefficiently by testing 
 ainst both sense and anti-sense versions of a sequence. 
 It is entirely equivalent to test a regexp containing both sense and 
 anti-sense versions of the *pattern* against one copy of the sequence.
 The latter approach is much more efficient since:
-
+ 
    1) You need only one copy of the sequence.
    2) Only one regexp is executed.
    3) Regexp patterns are typically much smaller than sequences.
@@ -175,8 +175,8 @@ Currently, this module only supports patterns using a grep-like syntax.
 
 =head1 USAGE
 
-A simple demo script is included with the central Bioperl distribution
-(L<INSTALLATION>) and is also available from:
+A simple demo script is included with the central Bioperl distribution (L<INSTALLATION>)
+and is also available from:
 
     http://bio.perl.org/Core/Examples/seq_pattern.pl
 
@@ -192,18 +192,18 @@ A simple demo script is included with the central Bioperl distribution
 
 =head2 Mailing Lists 
 
-User feedback is an integral part of the evolution of this and other
-Bioperl modules.  Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other Bioperl modules.
+Send your comments and suggestions preferably to one of the Bioperl mailing lists.
+Your participation is much appreciated.
 
-    bioperl-l@bioperl.org              - General discussion
-    http://bio.perl.org/MailList.html  - About the mailing lists
+    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
+    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
+    http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track the bugs and 
+their resolution. Bug reports can be submitted via email or the web:
 
     bioperl-bugs@bio.perl.org                   
     http://bio.perl.org/bioperl-bugs/           
@@ -241,10 +241,10 @@ modify it under the same terms as Perl itself.
 #####################################################################################
 
 
-=head1 new
+=head1 _initialize
 
- Title     : new
- Usage     : my $seqpat = new Bio::Tools::SeqPattern();
+ Title     : _initialize
+ Usage     : n/a; automatically called by Bio::Root::Object::new()
  Purpose   : Verifies that the type is correct for superclass (Bio::Seq.pm)
            : and calls superclass constructor last.
  Returns   : n/a
@@ -253,32 +253,34 @@ modify it under the same terms as Perl itself.
  Comments  : The process of creating a new SeqPattern.pm object
            : ensures that the pattern string is untained.
 
-See Also   : L<_untaint_pat>(), B<Bio::Root::RootI::new()>, 
-             B<Bio::Seq::_initialize()>
+See Also   : L<_untaint_pat>(), B<Bio::Root::Object::new()>, B<Bio::Seq::_initialize()>
 
 =cut
 
 #----------------
-sub new {
+sub _initialize {
 #----------------
-    my($class, %param) = @_;
+    my($self, %param) = @_;
     
-    my $self = $class->SUPER::new(%param);
-    my ($seq,$type) = $self->_rearrange([qw(SEQ TYPE)], %param);
+    my($seq, $type) = $self->_rearrange([qw(SEQ TYPE)], %param);
 
     $seq || $self->throw("Empty pattern.");
-    my $t;
+
     # Get the type ready for Bio::Seq.pm
     if ($type =~ /nuc|[dr]na/i) {
-	$t = 'Dna';
+	$param{-TYPE} = 'Dna';
     } elsif ($type =~ /amino|pep|prot/i) {
-	$t = 'Amino';
+	$param{-TYPE} = 'Amino';
     }
-    $seq =~ tr/a-z/A-Z/;  #ps 8/8/00 Canonicalize to upper case
-    $self->str($seq);
-    $self->type($t);
 
-    return $self;
+    my $make = $self->SUPER::_initialize(%param);
+#	 if($self->make() =~ /^nuc/i) {
+#	     $param{-SEQ} = $self->_expand_nuc($param{-SEQ}); 
+#	 } else {
+##	    $param{-SEQ} = $self->_expand_pep($param{-SEQ});  #unimplemented here.
+#	 }
+
+    $make;
 }
 
 
@@ -326,6 +328,8 @@ sub alphabet_ok {
     1;
 }
 
+
+
 =head1 expand
 
  Title     : expand
@@ -489,7 +493,7 @@ See Also   : B<Bio::Seq::revcom()>, L<_fixpat_1>(), L<_fixpat_2>(), L<_fixpat_3>
 
 =cut
 
-#-----------'
+#-----------
 sub revcom {
 #-----------
     my($self,$expand) = @_;
@@ -500,9 +504,7 @@ sub revcom {
 #    return $self->{'_rev'} if defined $self->{'_rev'};
 
     $expand ||= 0;
-    my $str = $self->str;
-    $str =~ tr/acgtrymkswhbvdnxACGTRYMKSWHBVDNX/tgcayrkmswdvbhnxTGCAYRKMSWDVBHNX/;
-    my $rev = CORE::reverse $str;
+    my $rev = $self->SUPER::revcom->str;  ## Invoke Bio::Seq::revcom()
     $rev    =~ tr/[](){}<>/][)(}{></;
 
     if($expand) {
@@ -527,11 +529,7 @@ sub revcom {
     
      $fixrev = _fixpat_5($fixrev);
 #    print "FIX 5: $fixrev";<STDIN>;
-
-##### Added by ps 8/7/00 to allow non-greedy matching
-     $fixrev = _fixpat_6($fixrev);
-#    print "FIX 6: $fixrev";<STDIN>;
-
+    
 #    $self->{'_rev'} = $fixrev;
 
      return new Bio::Tools::SeqPattern(-seq =>$fixrev, -type =>$self->type);
@@ -672,17 +670,17 @@ sub _fixpat_3 {
 #	$pat =~ s/(.+)(\{\S+\})(\(\w+\))(.*)/$1#$3$2$4/ or do{ push @done, $pat; last; };
 	if( $pat =~ /(.*)(.)(\{\S+\})(\(\w+\))(.*)/) {
 	    $newpat = "$1#$2$4$3$5";
-##ps	    $oldpat = "$1#$2$3$4$5";
+	    $oldpat = "$1#$2$3$4$5";
 #	    print "1: $1\n2: $2\n3: $3\n4: $4\n5: $5\n";
-##ps	    $braces = $3;
-##ps	    $braces =~ s/[{}]//g;
-##ps	    if( exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
-##ps		$pat = $oldpat;  # Don't change it. Already processed.
+	    $braces = $3;
+	    $braces =~ s/[{}]//g;
+	    if( exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
+		$pat = $oldpat;  # Don't change it. Already processed.
 #		print "saved pat: $pat";<STDIN>;
-##ps	    } else {
+	    } else {
 #		print "new pat: $newpat";<STDIN>;
 		$pat = $newpat;  # Change it.
-##ps	    }
+	    }
 	} elsif( $pat =~ /^(\{\S+\})(\(\w+\))(.*)/) {
 	    $pat = "#$2$1$3";
 	} else { 
@@ -727,8 +725,7 @@ sub _fixpat_4 {
 #	    print "1: $1\n2: $2\n3: $3\n4: $4\n5: $5\n";
 	    $braces = $3;
 	    $braces =~ s/[{}]//g;
-	    if( (defined $braces and defined $2) and
-		exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
+	    if( exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
 		$pat = $oldpat;  # Don't change it. Already processed.
 #		print "saved pat: $pat";<STDIN>;
 	    } else {
@@ -801,99 +798,6 @@ sub _fixpat_5 {
     return join('', reverse @done);
 }
 
-
-
-
-
-############################
-#
-#  PS: Added 8/7/00 to allow non-greedy matching patterns
-#
-######################################
-
-=head1 _fixpat_6
-
- Title     : _fixpat_6
- Usage     : n/a; called automatically by revcom()
- Purpose   : Utility method for revcom()
-           : Converts all ?Y{5,7}  ---> Y{5,7}?
-           :          and ?(XXX){5,7}  ---> (XXX){5,7}?
-           :          and ?[XYZ]{5,7}  ---> [XYZ]{5,7}?
- Returns   : String (the new, partially reversed pattern)
- Argument  : String (the expanded, partially reversed pattern)
- Throws    : n/a
-
-See Also   : L<revcom>()
-
-=cut
-
-#--------------
-sub _fixpat_6 {
-#--------------
-    my $pat = shift;
-    my (@done,@parts);
-
-   @done = ();
-    while(1) {
-	$pat =~   /(.*)\?(\[\w+\]|\(\w+\)|\w)(\{\S+?\})?(.*)/ or do{ push @done, $pat; last; };
-     my $quantifier = $3 ? $3 : ""; # Shut up warning if no explicit quantifier
- 	$pat = $1.'#'.$2.$quantifier.'?'.$4;
-#	$pat = $1.'#'.$2.$3.'?'.$4;
-
-#	print "1: $1\n2: $2\n3: $3\n";
-#	print "modified pat: $pat";<STDIN>;
-	@parts = split '#', $pat;
-	push @done, $parts[1];
-	$pat = $parts[0];
-#	print "done: $parts[1]<---\nnew pat: $pat<---";<STDIN>;
-	last if not $pat;
-    }
-    return join('', reverse @done);
-
- }
-
-=head2 str
-
- Title   : str
- Usage   : $obj->str($newval)
- Function: 
- Returns : value of str
- Args    : newvalue (optional)
-
-
-=cut
-
-sub str{
-   my $obj = shift;
-   if( @_ ) {
-      my $value = shift;
-      $obj->{'str'} = $value;
-    }
-    return $obj->{'str'};
-
-}
-
-=head2 type
-
- Title   : type
- Usage   : $obj->type($newval)
- Function: 
- Returns : value of type
- Args    : newvalue (optional)
-
-
-=cut
-
-sub type{
-   my $obj = shift;
-   if( @_ ) {
-      my $value = shift;
-      $obj->{'type'} = $value;
-    }
-    return $obj->{'type'};
-
-}
-
 1;
 __END__
 
@@ -905,29 +809,26 @@ __END__
 
 =head2 Data Members
 
-Information about the various data members of this module is provided
-for those wishing to modify or understand the code. Two things to bear
-in mind:
+Information about the various data members of this module is provided for those 
+wishing to modify or understand the code. Two things to bear in mind: 
 
 =over 4
 
 =item 1 Do NOT rely on these in any code outside of this module. 
 
-All data members are prefixed with an underscore to signify that they
-are private.  Always use accessor methods. If the accessor doesn't
-exist or is inadequate, create or modify an accessor (and let me know,
-too!).
+All data members are prefixed with an underscore to signify that they are private.
+Always use accessor methods. If the accessor doesn't exist or is inadequate, 
+create or modify an accessor (and let me know, too!). 
 
 =item 2 This documentation may be incomplete and out of date.
 
-It is easy for this documentation to become obsolete as this module is
-still evolving.  Always double check this info and search for members
-not described here.
+It is easy for this documentation to become obsolete as this module is still evolving. 
+Always double check this info and search for members not described here.
 
 =back
 
-An instance of Bio::Tools::RestrictionEnzyme.pm is a blessed reference
-to a hash containing all or some of the following fields:
+An instance of Bio::Tools::RestrictionEnzyme.pm is a blessed reference to a hash
+containing all or some of the following fields:
 
  FIELD          VALUE
  ------------------------------------------------------------------------
@@ -943,4 +844,3 @@ to a hash containing all or some of the following fields:
 
 
 
-1;
