@@ -5,7 +5,7 @@
 # PURPOSE : To demonstrate parsing features of the Bio::Tools::Blast.pm module.
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : 3 Feb 1998
-# REVISION: $Id: parse_blast.pl,v 1.8 2000/03/22 10:20:11 sac Exp $
+# REVISION: $Id: parse_blast.pl,v 1.4 1999/04/25 08:14:18 sac Exp $
 # WEBSITE : http://bio.perl.org/Projects/Blast/
 # USAGE   : parse_blast.pl -h
 # EXAMPLES: parse_blast.pl -eg
@@ -16,14 +16,14 @@
 #
 # COMMENTS:
 #
-# Sample BLAST output files can be found in examples/blast/out/ of the 
-# distribution. This script can process Blast report files specified 
-# on the command line or supplied via a STDIN stream.
-# 
-# This demo script does not exercise all of the functionality of the Blast 
-# object. See parse_blast2.pl and parse_positions.pl script for some other
-# manipulations and the documentation in the Bio::Tools::Blast.pm, 
-# accessible from the above website or by running Blast.pm through pod2html.
+# Sample BLAST output files can be found in examples/blast/out/ of the distribution.
+# This script can process Blast report files specified on the command line or
+# supplied via a STDIN stream.
+#
+# This demo script does not exercise all of the functionality of the Blast object.
+# See parse2.pl and parse_positions.pl script for some other manipulations and 
+# the documentation in the Bio::Tools::Blast.pm, accessible from the above website
+# or by running Blast.pm through pos2html.
 #
 # TODO:
 #  * Create an example that shows how to parse with HTML-formatted
@@ -31,8 +31,8 @@
 #    directly.
 #
 # MODIFIED:
-#  sac, 11 Mar 1999: Merged parse_stream.pl with parse.pl to create
-#                    parse_blast.pl. Replaces parse_stream.pl and parse.pl.
+#  sac, 11 Mar 1999: Merged parse_stream.pl with parse.pl to create parse_blast.pl.
+#                    No longer any parse_stream.pl or parse.pl.
 #  sac,  4 Sep 1998: Added example of using -filt_func option.
 #  sac, 16 Jun 1998: Added installation comment, require statement comments.
 #                    Minor alteration of seq_inds() calls.
@@ -50,7 +50,7 @@ use vars qw($ID $VERSION $DESC $MONITOR %blastParam @objects
 	    $opt_in $opt_table $opt_compress $opt_filt_func);
 
 $ID      = 'parse_blast.pl';
-$VERSION = 0.05;
+$VERSION = 0.04;
 $DESC    = "Demonstrates parsing Blast reports using Bio::Tools::Blast.pm";
 
 @errs = ();
@@ -80,7 +80,6 @@ sub examples {
   ./$ID out/blastp.2.gz -signif 1e-15 -table 2
   ./$ID out/blastp.2.wu -check_all -filt_func '\$hit->gaps == 0' -table 2
   ./$ID out/blastp.205.gz -signif 1e-1 -nostats
-  ./$ID out/blastp.2.gz -noaligns -signif 1e-5
   ./$ID -signif 1e-5 -table 1 < out/tblastn.2 > parsed.out
   ./$ID out/blastx.2.email.gz -table 1 -signif 1e-4  
   ./$ID out/blastn.2* -table 1 -best -nostats > parsed.out2
@@ -98,15 +97,10 @@ STREAM PARSING:
   gapped, ungapped, etc.). Most of the time, -noshare is unnecessary
   since all reports have the same program, version, gapping, etc.
 
-  The "print_blasts.pl dir" syntax or the parse_multi.pl script are 
+  THe "print_blasts.pl dir" syntax or the parse_multi.pl script are 
   recommended when working with large numbers of Blast reports (thousands).
   The Blasts reports located in "dir" can be compressed or not. 
 
-  WARNING:
-  Parsing large numbers of Blast reports can lead to serious
-  memory usage problems. See documentation in parse_multi.pl and
-  Blast.pm for more information (including a workaround).
-
 QQ_EG_QQ
 }
 
@@ -123,7 +117,6 @@ my ($blast_obj);
 
 if(@ARGV) {
     # Building object(s) from files specified on command line.
-    # Each file should contain one report.
     # Note that we don't really need to capture the $blast_object 
     # created by create_blast() since we can always access it via
     # the global $blastObj defined in blast_config.pl.
@@ -153,8 +146,8 @@ if(@ARGV) {
 	print STDERR ".", $count % 50 ? '' : "\n";
     }
 } else {
-    # @ARGV is empty. Build Blast objects from STDIN stream. 
-    # May contain one or more reports.
+    # Building object from STDIN. Expecting only one Blast report.
+    # To parse a stream of Blast reports, use parse_stream.pl.
     print STDERR "\nParsing Blast stream from STDIN.\n";
     if($opt_table) {
       # Process each Blast as you go.
