@@ -15,7 +15,7 @@
 #     Assorted updates associated with the new Bio:: modules.
 #----------------------------------------------------------
 
-use lib "/home/brad/bioperl/bioperl-live/";
+use lib "/home/sac";
 use Bio::Seq;
 use Bio::Tools::RestrictionEnzyme qw(@RE_available);
 
@@ -30,7 +30,7 @@ eval{
     $seq = new Bio::Seq(-ID  =>'test_seq', 
 			-SEQ =>$sequence); 
     
-    $re  = new Bio::Tools::RestrictionEnzyme(-name=>'EcoRI');
+    $re  = new Bio::Tools::RestrictionEnzyme(-NAME=>'EcoRI');
 };
 $@ && die "\n*** TROUBLE BUILDING OBJECTS:\n$@\n"; 
 
