@@ -1,4 +1,6 @@
-#!/usr/bin/perl
+#!/usr/local/bin/perl
+
+
 =head1 NAME
 
 bpfetch.pl - fetches sequences from bioperl indexed databases
@@ -21,8 +23,8 @@ Fetches sequences using the DB access systems in Bioperl. The most
 common use of this is to fetch sequences from bioperl indices built
 using bpindex.pl, or to fetch sequences from the NCBI website
 
-The format for retrieving sequences is delibrately like the
-GCG/EMBOSS format like the following:
+The format for retrieving sequences is delibrately like GCG/EMBOSS
+format, going
 
   db:name
 
@@ -42,7 +44,7 @@ db information
 =head1 OPTIONS
 
   -fmt  <format> - Output format
-                   Fasta (default), EMBL, Raw, swiss or GCG
+                   Fasta (default), EMBL, Raw or GCG
   -acc           - string is an accession number, not an
                    id. 
 
@@ -77,7 +79,6 @@ These modules can be used directly, which is far better than using
 this script as a system call or a pipe to read from. Read the
 source code for bpfetch to see how it is used.
 
-
 =head1 EXTENDING IT
 
 bpfetch uses a number of different modules to provide access to
@@ -94,27 +95,28 @@ obviously).
 
 =head1 FEEDBACK
 
-=head2 Mailing Lists
+=head2 Mailing Lists 
 
 User feedback is an integral part of the evolution of this and other
-Bioperl modules. Send your comments and suggestions preferably to
-the Bioperl mailing list.  Your participation is much appreciated.
+Bioperl modules.  Send your comments and suggestions preferably to one
+of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
+    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
+    http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+the bugs and their resolution. Bug reports can be submitted via email
+or the web:
 
-  bioperl-bugs@bioperl.org
-  http://bioperl.org/bioperl-bugs/
+    bioperl-bugs@bio.perl.org                   
+    http://bio.perl.org/bioperl-bugs/           
 
 =head1 AUTHOR
 
-Ewan Birney E<lt>birney@ebi.ac.ukE<gt>
+Ewan Birney, birney@sanger.ac.uk
 
 =cut
 
@@ -132,12 +134,10 @@ BEGIN {
     eval {
 	require Bio::Index::Fasta;
 	require Bio::Index::EMBL;
-	require Bio::Index::Swissprot;
         require Bio::DB::GenBank;
         require Bio::DB::GenPept;
-        require Bio::DB::EMBL;
         require Bio::SeqIO;
-
+	
     };
     if ( $@ ) {
 	# one up from here is Bio directory - we hope!
@@ -145,10 +145,8 @@ BEGIN {
 	eval {
 	    require Bio::Index::Fasta;
 	    require Bio::Index::EMBL;
-	    require Bio::Index::Swissprot;
             require Bio::DB::GenBank;
             require Bio::DB::GenPept;
-            require Bio::DB::EMBL;
             require Bio::SeqIO;
 	};
 	if ( $@ ) {
@@ -223,20 +221,18 @@ foreach my $arg ( @ARGV ) {
 	SWITCH : {
 	    $_ = $meta;
 	    /^net$/ && do {
-		if( $db =~ /genbank/i ) {
+		if( $db =~ /genbank/ ) {
 		    $dbobj = Bio::DB::GenBank->new();
 		}
-		elsif( $db =~ /genpept/i ) {
+		elsif( $db =~ /genpept/ ) {
 		    $dbobj = Bio::DB::GenPept->new();
-		} elsif( $db =~ /embl/i ) {
-		    $dbobj = Bio::DB::EMBL->new();
-                } else {
+		} else {
 		    die "Net database $db not available";
 		}
 		last SWITCH;
 	    };
 	    /^ace$/ && do {
-
+		
 		# yank in Bio::DB::Ace at runtime
 		eval {
 		    require Bio::DB::Ace;		    
@@ -282,8 +278,8 @@ foreach my $arg ( @ARGV ) {
     # the sequence index databases and the GenBank/GenPept do already
     #
 
-    if( ! $dbobj->isa('Bio::DB::RandomAccessI') ) {
-	warn("$db in $arg does not inherit from Bio::DB::RandomAccessI, so is not expected to work under the DB guidlines. Going to try it anyway");
+    if( ! $dbobj->isa('Bio::DB::BioSeqI') ) {
+	warn("$db in $arg does not inherit from Bio::DB::BioSeqI, so is not expected to work under the DB guidlines. Going to try it anyway");
     }
 
     eval {
